from typing import Literal, Annotated

from fastapi import APIRouter, Depends

from src.core.api_tips_integrate.constants import DONATES_SUM_PERIODS
from src.core.api_tips_integrate.schemas import CreateTipSchema
from src.core.api_tips_integrate.service import create_payment_link_for_tip_service
from src.core.common.dependencies import http_bearer, data_from_token
from src.core.common.schemas import TokenPayloadSchema, PaymentLinkSchema

router = APIRouter(
    tags=["Tips Integrate"],
)


@router.get(
    path="/last-payments"
)
async def get_last_donates(
        token: Annotated[str, Depends(http_bearer)],
):
    pass


@router.get(
    path="/summary-payments"
)
async def get_summary_payments_for_period(
        token: Annotated[str, Depends(http_bearer)],
        period: DONATES_SUM_PERIODS,
):
    pass


@router.post(
    path="/payment-request",
    response_model=PaymentLinkSchema,
)
async def create_payment_request(
        jwt_data: Annotated[TokenPayloadSchema, Depends(data_from_token)],
        create_tip_schema: CreateTipSchema,
):
    return await create_payment_link_for_tip_service(
        jwt_data=jwt_data,
        create_tip_schema=create_tip_schema,
    )
